diff -Naur nrpe-2.2/sample-config/nrpe.cfg.in nrpe-2.2-weak-rand-seed/sample-config/nrpe.cfg.in
--- nrpe-2.2/sample-config/nrpe.cfg.in	2006-01-21 02:03:22.000000000 +0100
+++ nrpe-2.2-weak-rand-seed/sample-config/nrpe.cfg.in	2006-01-23 19:40:27.920649800 +0100
@@ -90,6 +90,19 @@
 
 
 
+# SSL WITHOUT /dev/urandom
+# This directive allows you to use SSL even if your system does not have
+# a /dev/random or /dev/urandom (on purpose or because the necessary patches
+# were not applied). The random number generator will be seeded from a file
+# which is either a file pointed to by the environment valiable $RANDFILE
+# or $HOME/.rnd. If neither exists, the pseudo random number generator will
+# be initialized and a warning will be issued.
+# Values: 0=only seed from /dev/[u]random, 1=also seed from weak randomness
+
+#allow_weak_random_seed=1
+
+
+
 # INCLUDE CONFIG FILE
 # This directive allows you to include definitions from an external config file.
 
diff -Naur nrpe-2.2/src/nrpe.c nrpe-2.2-weak-rand-seed/src/nrpe.c
--- nrpe-2.2/src/nrpe.c	2006-01-21 20:23:36.000000000 +0100
+++ nrpe-2.2-weak-rand-seed/src/nrpe.c	2006-01-23 19:39:16.797015400 +0100
@@ -62,6 +62,8 @@
 
 int     allow_arguments=FALSE;
 
+int     allow_weak_random_seed=FALSE;
+
 int     show_help=FALSE;
 int     show_license=FALSE;
 int     show_version=FALSE;
@@ -77,6 +79,8 @@
 	char buffer[MAX_INPUT_BUFFER];
 #ifdef HAVE_SSL
 	DH *dh;
+	char seedfile[FILENAME_MAX];
+	int i,c;
 #endif
 
 	result=process_arguments(argc,argv);
@@ -187,6 +191,22 @@
 		SSLeay_add_ssl_algorithms();
 		meth=SSLv23_server_method();
 		SSL_load_error_strings();
+		if (allow_weak_random_seed && (RAND_status() == 0)) {
+			if (RAND_file_name(seedfile, sizeof(seedfile) - 1))
+				if (RAND_load_file(seedfile, -1))
+					RAND_write_file(seedfile);
+			if (RAND_status() == 0){
+				syslog(LOG_ERR,"Warning: SSL/TLS uses a weak random seed which is highly discouraged");
+				for (i=0;i<500 && RAND_status() == 0;i++){
+					for (c=0;c<sizeof(seedfile);c+=sizeof(int)){
+						*((int *)(seedfile+c))=rand();
+						}
+					RAND_seed(seedfile, sizeof(seedfile));
+					}
+				}
+			}
+
+
 		if((ctx=SSL_CTX_new(meth))==NULL){
 			syslog(LOG_ERR,"Error: could not create SSL context.\n");
 			exit(STATE_CRITICAL);
@@ -405,6 +425,9 @@
 			        }
 		        }
 
+		else if(!strcmp(varname,"allow_weak_random_seed"))
+			allow_weak_random_seed=(atoi(varvalue)==1)?TRUE:FALSE;
+
 		else if(!strcmp(varname,"pid_file"))
 			pid_file=strdup(varvalue);
 
